"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.install = exports.tagFromVersion = exports.versionFromPackageJson = void 0;
const path_1 = __importDefault(require("path"));
const fs_1 = __importDefault(require("fs"));
const chalk_1 = __importDefault(require("chalk"));
const asset_1 = require("./asset");
exports.versionFromPackageJson = require('../package.json').version;
function tagFromVersion(version) {
    return `v${version}`;
}
exports.tagFromVersion = tagFromVersion;
function install({ version = exports.versionFromPackageJson, destDir = process.env.HASURA_CLI_DEST_DIR || '.', fileName = process.env.HASURA_CLI_DEST_FILENAME || 'hasura', platform = process.platform, verbose = false, } = {}) {
    return __awaiter(this, void 0, void 0, function* () {
        const tag = tagFromVersion(version);
        const url = yield asset_1.getUrl(tag);
        const log = (msg) => {
            if (verbose) {
                console.log(msg);
            }
        };
        log(chalk_1.default `
{bold.bgGreen.black hasura-cli}@{green ${exports.versionFromPackageJson}}
{blue Downloading} {bold Hasura CLI binary} {green ${tag}} from {bold ${url}}
`);
        const adjustedFileName = platform === 'win32' && !fileName.endsWith('.exe')
            ? `${fileName}.exe`
            : fileName;
        const dest = yield asset_1.download({
            url,
            destDir,
            fileName: adjustedFileName,
        });
        if (platform === 'win32') {
            fs_1.default.unlinkSync(path_1.default.resolve(destDir, 'hasura'));
        }
        log(chalk_1.default `
{bold.bgGreen.black hasura-cli}@{green ${exports.versionFromPackageJson}}
{green Installed!} {bold Hasura CLI binary} {green ${tag}} is installed to {bold ${dest}}
`);
        return dest;
    });
}
exports.install = install;
